==> mastapy-14.1.0rc1-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/basic_dynamic_load_rating_calculation_method.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.bearings import _1934

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar(
        "Self", bound="EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod"
    )


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod",)


class EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod

    A specific implementation of 'EnumWithSelectedValue' for 'BasicDynamicLoadRatingCalculationMethod' types.
    """

    __qualname__ = "BasicDynamicLoadRatingCalculationMethod"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod]",
    ) -> "_1934.BasicDynamicLoadRatingCalculationMethod":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1934.BasicDynamicLoadRatingCalculationMethod
        """
        return _1934.BasicDynamicLoadRatingCalculationMethod

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1934.BasicDynamicLoadRatingCalculationMethod.type_()

    @property
    def selected_value(self: "Self") -> "_1934.BasicDynamicLoadRatingCalculationMethod":
        """mastapy.bearings.BasicDynamicLoadRatingCalculationMethod

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(
        self: "Self",
    ) -> "List[_1934.BasicDynamicLoadRatingCalculationMethod]":
        """List[mastapy.bearings.BasicDynamicLoadRatingCalculationMethod]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-15.0.0b4-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/basic_dynamic_load_rating_calculation_method.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.bearings import _2073

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar(
        "Self", bound="EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod"
    )


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod",)


class EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod

    A specific implementation of 'EnumWithSelectedValue' for 'BasicDynamicLoadRatingCalculationMethod' types.
    """

    __qualname__ = "BasicDynamicLoadRatingCalculationMethod"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod]",
    ) -> "_2073.BasicDynamicLoadRatingCalculationMethod":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _2073.BasicDynamicLoadRatingCalculationMethod
        """
        return _2073.BasicDynamicLoadRatingCalculationMethod

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_BasicDynamicLoadRatingCalculationMethod]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _2073.BasicDynamicLoadRatingCalculationMethod.type_()

    @property
    @exception_bridge
    def selected_value(self: "Self") -> "_2073.BasicDynamicLoadRatingCalculationMethod":
        """mastapy.bearings.BasicDynamicLoadRatingCalculationMethod

        Note:
            This property is readonly.
        """
        return None

    @property
    @exception_bridge
    def available_values(
        self: "Self",
    ) -> "List[_2073.BasicDynamicLoadRatingCalculationMethod]":
        """List[mastapy.bearings.BasicDynamicLoadRatingCalculationMethod]

        Note:
            This property is readonly.
        """
        return None
